==> xl-security-2015.6.5-sources.jar: com/xebialabs/deployit/security/Permissions.java <==
package com.xebialabs.deployit.security;

import com.google.common.base.Function;
import com.google.common.base.Joiner;
import com.google.common.base.Predicate;
import com.google.common.base.Splitter;
import com.google.common.collect.*;
import com.xebialabs.deployit.checks.Checks;
import com.xebialabs.deployit.jcr.JcrConstants;
import com.xebialabs.deployit.jcr.JcrUtils;
import com.xebialabs.deployit.plugin.api.reflect.Type;
import com.xebialabs.deployit.repository.JcrPathHelper;
import com.xebialabs.deployit.repository.core.Securable;
import com.xebialabs.deployit.security.permission.Permission;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.GrantedAuthority;
import org.springframework.security.core.context.SecurityContextHolder;

import javax.jcr.Node;
import javax.jcr.Property;
import javax.jcr.RepositoryException;
import javax.jcr.Session;
import java.util.*;

public class Permissions {
    static final Splitter PERMISSION_SPLITTER = Splitter.on(',').omitEmptyStrings();
    static final Joiner PERMISSION_JOINER = Joiner.on(",").skipNulls();
    
    static Iterable<String> splitPrincipals(String principals) {
        if (principals == null) return Lists.newArrayList();
        return PERMISSION_SPLITTER.split(principals);
    }
    
    static Iterable<Integer> splitRoles(String roles) {
        return Iterables.transform(splitPrincipals(roles), new Function<String, Integer>() {
            public Integer apply(String input) {
                return Integer.valueOf(input);
            }
        });
    }
    
    static String joinRoles(Iterable<Integer> roles) {
        return PERMISSION_JOINER.join(roles);
    }
    
    static String joinRoles(Integer... roles) {
        return PERMISSION_JOINER.join(roles);
    }
    
    static Iterable<Integer> rolesToIds(Iterable<Role> roles) {
        return Iterables.transform(roles, new Function<Role, Integer>() {
            public Integer apply(Role input) {
                return input.getId();
            }
        });
    }

    public static ImmutableMap<Integer, Role> buildLookup(List<Role> roles) {
        return Maps.uniqueIndex(roles, new Function<Role, Integer>() {
            @Override
            public Integer apply(Role input) {
                return input.getId();
            }
        });
    }

    static List<String> getFullTreeAsSeparateNodesInChildToRootOrder(String onConfigurationItem) {
        ArrayList<String> list = Lists.newArrayList();
        for (int index = onConfigurationItem.indexOf('/'); index > -1; index = onConfigurationItem.indexOf('/', index + 1)) {
            list.add(onConfigurationItem.substring(0, index));
        }
        list.add(onConfigurationItem);

        Collections.reverse(list);

        logger.debug("Split off tree: {} to {}", onConfigurationItem, list);

        return list;
    }

    public static Authentication getAuthentication() {
        return SecurityContextHolder.getContext().getAuthentication();
    }

    public static String getAuthenticatedUserName() {
        return getAuthentication() != null ? getAuthentication().getName() : null;
    }

    public static void clearSecurityContext() {
        SecurityContextHolder.clearContext();
    }

    public static Collection<String> authenticationToPrincipals(Authentication authentication) {
        final String name = authentication.getName();
        final Iterable<String> authorities = getAuthorities(authentication);
        final Collection<String> allPrincipals = Sets.newHashSet(authorities);
        allPrincipals.add(name);
        logger.trace("All principals for user [{}] are: {}", authentication.getName(), allPrincipals);
        return allPrincipals;
    }

    private static Iterable<String> getAuthorities(Authentication authentication) {
        return Iterables.transform(authentication.getAuthorities(), new Function<GrantedAuthority, String>() {
            @Override
            public String apply(GrantedAuthority input) {
                return input.getAuthority();
            }
        });
    }

    static Node readSecurable(String securable, Session session) throws RepositoryException {
        Node node = session.getNode(JcrPathHelper.getAbsolutePathFromId(securable));
        checkSecurable(node);
        return node;
    }

    static void checkSecurable(Node node) throws RepositoryException {
        String type = node.getProperty(JcrConstants.CONFIGURATION_ITEM_TYPE_PROPERTY_NAME).getString();
        Checks.checkArgument(isSecurable(node), "Cannot set permission on [%s] because it is not Securable [%s]", JcrPathHelper.getIdFromAbsolutePath(node.getPath()), type);
    }
    
    static boolean isSecurable(Node node) throws RepositoryException {
        String type = node.getProperty(JcrConstants.CONFIGURATION_ITEM_TYPE_PROPERTY_NAME).getString();
        return Type.valueOf(type).isSubTypeOf(Type.valueOf(Securable.class));
    }
    
    static Map<String, String> readPermissionMap(Node s) throws RepositoryException {
        Map<String, String> permissions = Maps.newHashMap();
        if (s.hasProperty(Securable.SECURITY_PERMISSIONS_PROPERTY)) {
            Property securityPermissions = s.getProperty(Securable.SECURITY_PERMISSIONS_PROPERTY);
            permissions = JcrUtils.readMap(securityPermissions);
        }
        return permissions;
    }
    
    static void writePermissionMap(Node s, Map<String, String> permissions) throws RepositoryException {
        JcrUtils.writeMap(s, Securable.SECURITY_PERMISSIONS_PROPERTY, permissions);
    }

    private static final Logger logger = LoggerFactory.getLogger(Permissions.class);

    public static Collection<Permission> isApplicableTo(Collection<Permission> values, final String id) {
        return Collections2.filter(values, new Predicate<Permission>() {
            public boolean apply(Permission input) {
                return !input.isApplicableTo(id);
            }
        });
    }
}

==> xl-security-2017.1.1-sources.jar: com/xebialabs/deployit/security/Permissions.java <==
package com.xebialabs.deployit.security;

import java.util.Collection;
import java.util.HashSet;
import java.util.stream.Collectors;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.GrantedAuthority;
import org.springframework.security.core.context.SecurityContextHolder;

import com.xebialabs.deployit.security.permission.Permission;

public class Permissions {
    public static Authentication getAuthentication() {
        return SecurityContextHolder.getContext().getAuthentication();
    }

    public static String getAuthenticatedUserName() {
        return getAuthentication() != null ? getAuthentication().getName() : null;
    }

    public static Collection<String> authenticationToPrincipals(Authentication authentication) {
        final String name = authentication.getName();
        final Collection<String> allPrincipals = authentication.getAuthorities().stream().map(GrantedAuthority::getAuthority).collect(Collectors.toCollection(HashSet::new));
        allPrincipals.add(name);
        logger.trace("All principals for user [{}] are: {}", authentication.getName(), allPrincipals);
        return allPrincipals;
    }

    public static void clearSecurityContext() {
        SecurityContextHolder.clearContext();
    }

    private static final Logger logger = LoggerFactory.getLogger(Permissions.class);

    public static Collection<Permission> isApplicableTo(Collection<Permission> values, final String id) {
        return values.stream().filter((p) -> !p.isApplicableTo(id)).collect(Collectors.toList());
    }
}
